---
title: V04 Board
description: 
published: true
date: 2023-11-22T20:21:00.619Z
tags: boards, hardware, v0.4
editor: markdown
dateCreated: 2020-01-06T01:53:44.099Z
---

# V0.4 Board
## Overview

The v0.4 board is a testing board that was developed with the goals of reproducing the existing v0.3 boards capabilities, but with the following improvements:

- Lower cost (Primarily due to reduced size, but also some component changes)
- More compatible with off the shelf cases/enclosures
- Stepper-style IAC driver option
- Has a single 40 pin connector for all IO (Excluding 12v power)

> **Note:** The v0.4 is **NOT** intended as a replacement for the v0.3 line of boards! The 2 are designed with different goals in mind. The v0.4 is intended to be integrated more closely into existing wiring, with the aim being that interface boards can be used to easily connect through the IDC40 connector. Unless you understand the interface on the v0.4 board and believe it is the best option for your install, the v0.3 may well be a better option for you.
{.is-warning}


## Board Features

The v0.4 boards includes the following features:

-   4 injector channels
-   4 Ignition outputs
-   Fully protected input channels for CLT, IAT, TPS and O2
-   Optional VR conditioner mount on crank and cam inputs
-   MAP sensor mount location
-   DRV8825 stepper module mount location
-   4 medium-current spare outputs (e.g., fuel pump, thermo fan, boost control, VVT, etc)
-   5 unpopulated/configured optional low-current spare outputs in "proto" section, including tachometer-out
-   A single 40-pin IDC connector includes all pins required for the board with the exception of the 12v input

## Physical Layout

Note that there are some differences between the various versions of the board, however the pinouts on the main IDC40 connector remain the same.

Note: Injector Pins have 1/2 and 2/2 markings this is to more easily and clearly route injectors for semi sequential and batch modes. If the application requires less than 4 injectors simply use either pin 1/2 or 2/2. If the application requires 5 or more injectors it is recommended to use both 1/2 and 2/2 when available to more evenly distribute the current from the injector coils triggerting. See [Injector Wiring](/wiring/Injector_wiring) for more specific details. 

![v0_4_board_annotated_1.jpg](/img/boards/v0_4_board_annotated_1.jpg){.align-left width=50%}


| Pin \# | Function                                 |
| ------ | ---------------------------------------- |
| 1      | Injector 1 - Pin 1/2                     |
| 2      | Injector 2 - Pin 1/2                     |
| 3      | Injector 3 - Pin 1/2                     |
| 4      | Injector 3 - Pin 2/2                     |
| 5      | Injector 4 - Pin 1/2                     |
| 6      | Injector 4 - Pin 2/2                     |
| 7      | Ignition 1                               |
| 8      | Ignition 4                               |
| 9      | Ground                                   |
| 10     | Ground                                   |
| 11     | MAP Sensor (0v-5v)                       |
| 12     | Ground                                   |
| 13     | 5v                                       |
| 14     | Proto Area 1 (0.4.4b+ Flex Sensor)       |
| 15     | Proto Area 2 (0.4.4b+ Fan)               |
| 16     | Proto Area 3 (0.4.4b+ Fuel Pump)         |
| 17     | Proto Area 4 (0.4.4b+ Tachometer)        |
| 18     | Proto Area 5 (0.4.4b+ Clutch)            |
| 19     | Coolant (CLT)                            |
| 20     | Inlet Air Temp (IAT)                     |
| 21     | O2 Sensor                                |
| 22     | TPS input                                |
| 23     | Ground                                   |
| 24     | Cam Input / VR2+                         |
| 25     | Crank Input / VR1+                       |
| 26     | VR2- (Not used for hall sensor)          |
| 27     | VR1- (Not used for hall sensor)          |
| 28     | 5v                                       |
| 29     | Idle Stepper 2B                          |
| 30     | Idle Stepper 2A                          |
| 31     | Idle Stepper 1A                          |
| 32     | Idle Stepper 1B                          |
| 33     | Ignition 3                               |
| 34     | Ignition 2                               |
| 35     | Boost                                    |
| 36     | Idle 2 (For use with 3 wire idle valves) |
| 37     | PWM Idle                                 |
| 38     | VVT                                      |
| 39     | Injector 2 - Pin 2/2                     |
| 40     | Injector 1 - Pin 2/2                     |

## Board Assembly

Assembly of a complete board is virtually identical to the v0.3 and remains relatively straightforward with all components being through hole and labelled on the board. Whilst it does not technically matter which order components are installed, the following is recommended for simplicity:

1. All resistors
2. All diodes (Including LEDS)
  > **NOTE:** Boards version 0.4.3c and prior short leg of LED goes in round pads, and boards version 0.4.3d and higher short leg of LED goes in square pads.
{.is-warning}
3. All capacitors
  > Take note that C14 and C16 are polarised capacitors, meaning that they must be put in the correct way around. The capacitors should be marked with a + sign on one side. On the PCB, the positive side is indicated by a line on the capacitor symbol.
{.is-warning}

![capacitor_orientation.png](/img/hardware/capacitor_orientation.png){.align-center width=180}

4. All jumper headers (JP\*)
5. Arduino pins:
    * **Suggested method**: Break header pins into required lengths and insert into an Arduino Mega. Place the board over the top of the pins and solder in place
    * Note that not all the pins on the end double row need to be populated (Though there's no harm in doing so). The odd numbered pins (Eg D23, D25 .. DD53) do not need pins on them.
6.  IDC 40 connector
7.  IC sockets
8.  All screw terminals
9.  All MOSFETs
10.  Power regulator
11.  MAP sensor (If used)
  >  **NOTE:** Self assembly boards 0.4.3c and prior have the MAP sensor with the hole at the top. Self assembly boards 0.4.3d and later and all surface mount boards will have the hole on the bottom.
{.is-warning}


### Assembly Instruction video

v0.4 assembly video available at [YouTube](https://www.youtube.com/watch?v=-UoFbUasFGY)

## Board Configuration

The board can be configured in multiple ways depending on the hardware you use and way your setup is configured.

### Board default I/O

Multiple functions within Speeduino have adjustable inputs or outputs or can be set to Board Default. The following are the Default pin outs for the v0.4, however all of these functions can be reassigned to other pins if required (Eg to use the onboard high current outputs)

| Function                    | Board output                     | Arduino pin |
|-----------------------------|----------------------------------|-------------|
| Boost control               | IDC Pin 35                       | 7           |
| VVT                         | IDC Pin 38                       | 4           |
| Idle 1                      | IDC Pin 37                       | 5           |
| Idle 2 (3 wire idle valves) | IDC Pin 36                       | 6           |
| Fuel pump                   | Proto area (45) (0.4.4b+ IDC 16) | 45          |
| Fan                         | Proto area (47) (0.4.4b+ IDC 15) | 47          |
| Tacho                       | Proto area (49) (0.4.4b+ IDC 17) | 49          |
| Launch / Clutch             | Proto area (51) (0.4.4b+ IDC 18) | 51          |
| VSS                         | Proto area (20) (0.4.3+)         | 20          |
| Flex Fuel (Ethanol)         | Proto area (Eth) (0.4.3+)        | 2           |

### Optional Components

If using a VR crank sensor, the board will require the addition of a VR conditioner. The board has been designed to work with the dual VR conditioner from JBPerf (http://www.jbperf.com/dual_VR/index.html) which will plug directly in. These have been out of stock to purchase directly for some time but can be built from the parts list as the instructions are still available. 

There is also an [official VR board](https://speeduino.com/shop/home/17-dual-vr-conditioner.html) that can be purchased from the speeduino shop which also plugs in directly.

Most partner resellers have their own conditioners with other features such as LEDs for when the signal is triggering high / low. Other 3rd party VR conditioners will also likely work but obviously not all configurations can be validated.


#### SP721 Over-voltage Protection

For users having difficulty obtaining the SP721 used in some versions, see info on the [SP721 Diode Alternate](/wiring/SP721_Diode_Alternate) page

### Jumper Configs

Depending on the type of crank and cam sensors you have, there are a number of jumpers that will need to be set.

Some VR sensors can send high AC voltage into the arduino board. If you are unsure of your sensor type identify it before connecting it to the board. Using a VR sensor with the ‘direct’ pins closed (JP2) and or (JP3) may cause damage to the microprocessor. Danger!

The jumpers that need setting are:

-   JP1 - This sets whether the Ignition outputs are 12v or 5v. Note that even if you set this to 12v you should \*\*NOT\*\* connect these directly to a high current coil. These outputs should only ever go to a logic level coil or an igniter
-   JP2 - Whether or not the RPM1 (Crank) input should be routed via the (Optional) VR conditioner. This should be set to VR when using either a VR sensor or a hall sensor that switches between 0v-12v
-   JP3 - Same as JP2, but for the RPM2 (Cam) input
-   JP4 - 1k pullup resistor for RPM1 input. Should be jumpered ('On') when a sensor is used that switches between ground and floating (Which is most hall effect sensors)
-   JP5 - Same as JP4, but for the RPM2 (Cam) input

To make this simpler, the most common sensor types and their required configurations are below:

| Crank Sensor              | Cam Sensor            | JP2  | JP3  | JP4 | JP5 |
|---------------------------|-----------------------|------|------|-----|-----|
| Hall sensor               | -                     | Hall/Direct | Off  | On  | Off |
| VR Sensor                 | -                     | VR/TSC   | Off  | Off | Off |
| Hall sensor               | Hall sensor           | Hall/Direct | Hall/Direct | On  | On  |
| VR Sensor                 | Hall sensor           | VR/TSC   | Hall/Direct | Off | On  |
| VR Sensor                 | VR sensor           | VR/TSC   | VR/TSC | Off | Off  |
| Hall Sensor                 | VR sensor           | Hall/Direct   | VR/TSC | On | Off  |

### 40-pin connection

You can solder wires directly to the board or use IDC (Insulation Displacement Contact) connectors. The 40-pin IDC is the connector that was used on computer drive ribbon cables for years and old computer cables can be used. A heavier cable, called DuPont cable is recommend for long term use though. Later in the IDE/ATA interfaces life the speed was increased and this required a new fine 80-wire cable. These cables are **NOT** compatible. Some of the pins are connected together causing the magic blue smoke to be released.

## Board revisions

| Version | Changes                                                                                                                                                                                                | BOM                                                                                                        |
|-----------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------|
| V0.4.4c | Small fixes from the b-version.                                                                     | Not Required                                                                                               |
| V0.4.4b | A new ground up, all SMD, board design that includes additional onboard drivers and protection circuits. It is electrically and physically compatible with all other v0.4 versions.                 | Not Required                                                                                               |
| V0.4.4  | Modified for easier automated assembly, including some SMD components and mounting the pressure sensor flat side up. Run/program switch added. Only sold officially as complete boards                 | Not Required                                                                                               |
| V0.4.3d | Newest THT design. Compared to previous design, TO220 cases now lay flat on the board, power circuit is improved, molex connector has been removed, ULN2003 is added for low current outputs and proto area is removed due to space constraints.   | [Download](https://github.com/speeduino/Hardware/blob/main/v0.4/THT/Latest/v0.4.3d%20BOM.xlsx) |
| V0.4.3  | Filter capacitors added to both primary and secondary RPM inputs. Voltage clamp added to secondary RPM input. Flex fuel input added to proto area                                                      | [Download](https://github.com/speeduino/Hardware/blob/main/v0.4/THT/Prior%20versions/v0.4.3/v0.4.3_bom.xlsx) |
| V0.4.2  | Considerable number of routing improvements. Neater proto area layout. Voltage clamp added to primary RPM input                                                                                        | [Download](https://github.com/speeduino/Hardware/blob/main/v0.4/THT/Prior%20versions/v0.4.2/v0.4.2_bom.xlsx) |
| V0.4.1  | Added Proto area. Replaced diode array with SP721. Added optional high current aux output socket (J5). Diode relocated on power circuit to prevent USB back feeding 5v onto 12v rail when ignition off | Same as v0.4.2                                                                                             |
| V0.4    | Initial release                                                                                                                                                                                        | [Download](https://github.com/speeduino/Hardware/blob/main/v0.4/THT/Prior%20versions/v0.4.0/v0.4_bom.xlsx)   |

Github for the 0.4 hardware designs: https://github.com/speeduino/Hardware/tree/main/v0.4

## Full pin number chart

Chart consist all pin numbers used in Speeduino Firmware for v0.4 boards. Pin numbers are Arduino Mega pin numbers. Not IDC pin numbers. This chart can be used as a guide when setting unused default outputs for some other use.

| Pin name              | Pin number           | Description |
|---------------------------|-----------------------|-----|
| pinInjector1 | 8 | Output pin injector 1
| pinInjector2 | 9 | Output pin injector 2
| pinInjector3 | 10 | Output pin injector 3
| pinInjector4 | 11 | Output pin injector 4
| pinInjector5 | 12 | Output pin injector 5
| pinInjector6 | 50 | CAUTION: Uses the same as Coil 4 below. 
| pinCoil1 | 40 | Pin for coil 1
| pinCoil2 | 38 | Pin for coil 2
| pinCoil3 | 52 | Pin for coil 3
| pinCoil4 | 50 | Pin for coil 4
| pinCoil5 | 34 | Pin for coil 5 (PLACEHOLDER)
| pinTrigger | 19 | The CAS pin
| pinTrigger2 | 18 | The Cam Sensor pin
| pinTrigger3 | 3 | The Cam sensor 2 pin (VVT2 input pin)
| pinTPS | A2 | TPS input pin
| pinMAP | A3 | MAP sensor pin
| pinIAT | A0 | IAT sensor pin
| pinCLT | A1 | CLS sensor pin
| pinO2 | A8 | O2 Sensor pin
| pinBat | A4 | Battery reference voltage pin
| pinDisplayReset | 48 |  OLED reset pin
| pinTachOut | 49 | Tacho output pin  (Goes to ULN2803)
| pinIdle1 | 5 | Single wire idle control
| pinIdle2 | 6 | 2 wire idle control
| pinBoost | 7 | Boost control
| pinVVT_1 | 4 | Default VVT output
| pinVVT_2 | 48 | Default VVT2 output
| pinFuelPump | 45 | Fuel pump output  (Goes to ULN2803)
| pinStepperDir | 16 | Direction pin  for DRV8825 driver
| pinStepperStep | 17 | Step pin for DRV8825 driver
| pinStepperEnable | 24 | Enable pin for DRV8825
| pinFan | 47 | Pin for the fan output (Goes to ULN2803)
| pinLaunch | 51 | Can be overwritten below
| pinFlex | 2 |  Flex sensor (Must be external interrupt enabled)
| pinResetControl | 43 | Reset control output
| pinBaro | A5 | Input pin for Baro sensor
| pinVSS | 20 | VSS input pin
| pinWMIEmpty | 46 |
| pinWMIIndicator | 44 |
| pinWMIEnabled | 42 |