---
title: Sensor Calibration
description: Steps for calibrating all analog sensor inputs
published: true
date: 2023-07-15T01:01:07.166Z
tags: 
editor: markdown
dateCreated: 2020-01-06T01:54:06.827Z
---

# Sensor Calibration

Before your Speeduino can correctly interpret the signals from the sensors, it must know which sensors you are using. Inputting this information into TunerStudio (TS) writes the correct calibration to your Speeduino. It is necessary to perform this step before you can effectively check your Speeduino build. Note that this is not tuning your system, but only telling it how to understand the signals from the sensors.

This should be completed after completing the Settings for your engine. Your computer must be connected to your Speeduino through TS to perform the calibrations.

## MAP Sensor

Open the **Tools** menu:

![Tuner Studio Tools Menu](/img/tuning/tools_menu.png){.align-center width=400}

Select **Calibrate Pressure Sensors**, the window below will open:

![MAP calibration](/img/tuning/MAP_calibration.png){.align-center width=400}

Select your MAP Sensor from the drop down list. If you used the MAP sensor in the bill of materials, this will be the MPX4250A. If you are using another MAP or one from the engine manufacturer, select it from the list. Click **Burn** to send the information to your Speeduino.

If used, the external Baro and EMAP (exhaust pressure) sensors can be calibrated in the same manner. 


## Coolant and Intake Temperature Sensors

Open the **Tools** menu and select **Calibrate Thermistor Tables**:

The sensor selected will be the **Coolant Temperature Sensor**. Select your sensor from the **Common Sensor Values** drop-down list. This will place the correct values into the temperature and resistance charts and the Bias resistor value. If your sensor is not listed, see [Entering Custom Values](#Entering_Custom_Values "wikilink") below.

Note that the standard Speeduino build is to have a 2490 ohm bias resistor, which is standard for sensors used by most manufacturers. If your sensor requires another value, you may need to change resistor R3 to the correct value for your sensor. You can try overriding the Bias Resistor Value with 2490 ohms, but check to be sure your sensor reads correctly in TS.

![CLT calibration](/img/tuning/CLT_calibration.png){.align-center width=450}

The same calibration can then be performed for the Inlet Air Temperature (IAT) sensor by changing the **Sensor Table** to **Air Temperature Sensor**:

![IAT calibration](/img/tuning/IAT_calibration.png){.align-center width=450}

Select your sensor from the **Common Sensor Values** drop-down list. This will place the correct values into the temperature and resistance charts and the Bias resistor value. Click **Write to Controller** to send this information to your Speeduino. If your sensor is not listed, see [Entering Custom Values](#Entering_Custom_Values "wikilink") below.

Note that the standard Speeduino build is to have a 2490 ohm bias resistor, which is standard for sensors used by most manufacturers. If your sensor requires another value, you may need to change resistor R3 to the correct value for your sensor. You can try overriding the Bias Resistor Value with 2490 ohms, but check to be sure your sensor reads correctly in TS.

### Entering Custom Values

Some sensors are not listed in the tables for the common sensors. If yours is not listed, you will need to enter the values into the fields your self. You will need two bits of information: 1. The value of your bias resistor (2490 if you used the standard values in the Bill of Materials, or you have a pre-made Speeduino), and 2. The resistance of your sensor at three different temperatures.

The sensor resistance can be generated by measuring the resistance of the sensor in ambient air, putting it in a freezer and then in boiling water. You will need a good multimeter and an accurate thermometer that measures -10C to 100C (14°F to 212°F). It is best to use jumper wires to allow the resistance of the sensor to be read without holding it in your hand (some sensors react quickly to temperature changes). Some sensors react slowly to temperature changes, so allow the sensor at least 10 minutes to reach a stable temperature, and then record the temperature and resistance observed.

In the **Calibrate Thermistor Tables** screen, first ensure the correct temperature unit is selected (**F** or **C**). Then record the bias resistor value and the temperature / resistance values in the fields. Click **Write to Controller** to send this information to your Speeduino.

Note that his procedure can also be used to enter the values of resistance on simulators for testing and troubleshooting. Two points should be remembered if you use simulator values – first, never enter zero for resistance. Although your simulator may go to zero, enter some small value above zero, say 10 ohms. Entering zero leads to false values in the firmware. Second – remember to enter the correct sensor values before installing your Speeduino!

## Oxygen Sensor 

Open the **Tools** menu again and select **Calibrate AFR Table**:

![O2 calibration](/img/tuning/O2_calibration.png){.align-center width=400}

Select your **Oxygen Sensor sensor** from the **Common Sensor Values** drop-down list. If you are using a custom Oxygen Sensor controller, select **Custom Linear WB** and then you can enter the values for **Volts** and **AFR** at two points (should be published in the controller manual).

Click **Write to Controller** to send this information to your Speeduino.

This will set up your Speeduino so that you can also run simulations to check your build before installation.


## Throttle Position Sensor

Before Speeduino can work correctly with your engine, you will also need to Calibrate the Throttle Position Sensor. This must be done using the throttle body and TPS used on the engine. It is best to do this while the throttle body is installed on the engine.

Open the **Tools** menu and select **Calibrate TPS**:

![TPS calibration](/img/tuning/TPS_calibration.png){.align-center width=480}

With the throttle closed, click the **Get Current** button beside the Closed Throttle ADC count field. Then move the throttle to full open and hold it there. Then click the **Get Current** button beside the Full Throttle ADC count field.

Click **Accept** to save the information to Speeduino.