---
title: Настройка зажигания Spark Settings
description: Configuration options for the ignition outputs
published: true
date: 2021-01-03T09:14:27.448Z
tags: 
editor: undefined
dateCreated: 2021-01-02T04:42:38.347Z
---

# Настройка зажигания Spark Settings
## Обзор

Диалоговое окно "Spark settings" (Настройки искры) содержит параметры функционирования выходов зажигания, в том числе, какие из 4 выходов IGN используются и как. Они критичны, и неправильные значения приводят к тому, что двигатель не запускается, и в некоторых случаях возможно повреждение оборудования. В этом диалоговом окне также содержится ряд вариантов фиксации опережения зажигания для тестирования и диагностики.

Проверьте эти параметры перед запуском двигателя.

Чтобы создать базовую карту синхронизации, которая даст вам лучшие числа, чем карта по умолчанию от быстрого загрузчика есть несколько инструментов онлайн, как: http://www.useasydocs.com/theory/spktable.htm использовать их на свой страх и риск и всегда слушать преддетонацию / детонацию. Лучше всего настраивать зажигание на трассе или диностенде.

## Настройки
![spark_settings.png](/img/ignition/spark_settings.png){.align-center width=500}

- **Spark Output mode** - Определяет, как будут выводиться импульсы зажигания, и зависит от вашей проводки зажигания. **Обратите внимание, что независимо от того, какая опция выбрана здесь, сигналы зажигания ВСЕГДА горят в числовом порядке (ie 1-&gt;2-&gt;3-&gt;4) до максимального количества выходов**. Порядок зажигания двигателя учитывается в порядке разводки.
    - **Wasted Spark** - Потраченная впустую искра. Количество выходов зажигания равно половине числа цилиндров и каждый выход будет срабатывать один раз за каждый оборот кривошипа. Поэтому одна искра будет иметь место во время такта сжатия, а другая - во время такта выпуска (она же "потраченная впустую" искра). Этот метод распространён на многих транспортных средствах 80-х и 90-х годов, которые поставлялись с конкретными отработанными искровыми катушками, но также могут использоваться с отдельными катушками, которые проводятся попарно. Отработанная искра будет работать только с эталоном угла поворота кривошипа (например, отсутствующее зубчатое кривошипное колесо без сигнала кулачка)
    - **Single Channel** - Одноканальный. Этот режим посылает все импульсы зажигания на IGN1 выход и используется, когда двигатель содержит распределитель (обычно с одной катушкой). Количество выходных импульсов на (кривошип) оборот равно половине числа цилиндров.
    - **Wasted COP** - Это удобный режим, в котором используется та же синхронизация, что и в опции "Wasted Spark", однако каждый импульс посылается на 2 выходы зажигания, а не на один. Это парные IGN1/IGN3 и IGN2/IGN4 (то есть, когда IGN1 высокий, IGN3 также будет высоким). Поскольку этот режим по-прежнему является бесполезным, требуется только положение кривошипа, и на один оборот кривошипа будет приходиться 1 импульс на пару. Этот режим может быть полезен в тех случаях, когда имеется 4 отдельных катушки, но полная последовательная работа либо не желательна, либо невозможна (например, когда отсутствует ссылка на кулачок).
    - **Sequential** - Последовательный - этот режим работает только на двигателях с 4 или менее цилиндрами (8 для платы Dropbear).
    - **Rotary** - Ванкели. Подробную информацию см. ниже.
- **Cranking advance** - Опережение при запуске - число абсолютных градусов (BTDC), на которые устанавливается синхронизация при прокрутке. Это переопределяет все другие модификаторы опережения синхронизации во время запуска.
-   **Spark output triggers** - <font color='red'>**ЭТО КРИТИЧЕСКАЯ НАСТРОЙКА!**</font> Выбор неправильной опции может привести к повреждению воспламенителей или катушек. Определяет, будет ли катушка срабатывать, когда выходной сигнал зажигания Speeduino становится ВЫСОКИМ или НИЗКИМ. Для ПОДАВЛЯЮЩЕГО большинства установок зажигания требуется установка **НИЗКИЙ УРОВЕНЬ** (т.е. зарядка/остановка катушки при высоком сигнале и ** искра ** при низком сигнале). В то время как для большинства установок зажигания требуется GOING LOW, существуют некоторые конфигурации, которые выполняют задержку синхронизации на модуле зажигания и зажигают катушку только тогда, когда они принимают сигнал HIGH от ECU.
-   **Fixed Angle** - Фиксированный угол. Используется для фиксации момента зажигания до определенного угла для испытания. Установка этого значения на любое значение, отличное от 0, приведет к использованию этого точного угла (т.е. к переопределению любых других настроек) при всех оборотах/точках нагрузки, за исключением случаев, когда выполняется прокрутка (при прокрутке всегда используется вышеупомянутая настройка "Опережение прокрутки"). Для нормальной работы этот параметр должен иметь значение 0.

### Зажигание для Ванкелей Rotary modes
![rotary_settings.png](/img/ignition/rotary_settings.png){.align-center width=450}

Speeduino поддерживает конфигурации зажигания, найденные в двигателях FC/FD RX7 и RX8, и эта опция становится доступной, когда режим зажигания Rotary выбран выше. Передний/задний угол разделения может быть установлен как функция текущей нагрузки двигателя.

- **FC** - Выходные данные конфигурируются для настройки Leading/Trailing, которая использовалась в FC RX7s. Проводка:
  - **IGN1** - Leading (wasted) sparks Ведущие (потраченные впустую) искры
  - **IGN2** - Trailing spark
  - **IGN3** - Trailing select
  - **IGN4** - Not used
- **FD** - Использует один и тот же отработанный искровой сигнал для обоих ведущих искр, как FC, но отдельные сигналы для задних искр. Проводка:
  - **IGN1** - Leading (wasted) sparks Ведущие (потраченные впустую) искры
  - **IGN2** - Front rotor trailing
  - **IGN3** - Rear rotor trailing
  - **IGN4** - Not used
- **RX8** - Для каждого искрового сигнала используются отдельные выходы. Проводка:
  - **IGN1** - Front rotor leading
  - **IGN2** - Rear rotor leading
  - **IGN3** - Front rotor trailing
  - **IGN4** - Rear rotor trailing